Skip to contents

Provides functions for fitting various penalized parametric and semi-parametric mixture cure models with different penalty functions, testing for a significant cure fraction, and testing for sufficient follow-up as described in Fu et al (2022)doi:10.1002/sim.9513 and Archer et al (2024)doi:10.1186/s13045-024-01553-6 . False discovery rate controlled variable selection is provided using model-X knock-offs.

Author

Maintainer: Kellie J. Archer archer.43@osu.edu (ORCID)

Authors:

  • Han Fu

Other contributors: